@@ -33,7 +33,6 @@
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h> /* needed by hildon-navigator-main.h */
-#include <log-functions.h>
 
 #ifdef HAVE_LIBHILDON
 #include <hildon/hildon-defines.h>
@@ -994,7 +993,6 @@ void
 hd_wm_watched_window_awake (HDWMWatchedWindow *win)
 {
   HDWMWatchableApp      *app;
-  osso_manager_t        *osso_man;
 
   app = hd_wm_watched_window_get_app(win);
 
@@ -1002,9 +1000,8 @@ hd_wm_watched_window_awake (HDWMWatchedWindow *win)
     {
       /* Relaunch it with RESTORED */
       hd_wm_watchable_app_set_launching (app, TRUE);
-      osso_man = osso_manager_singleton_get_instance();
-      osso_manager_launch(osso_man, hd_wm_watchable_app_get_service (app),
-			  RESTORED);
+      hd_wm_activate_service (hd_wm_watchable_app_get_service (app),
+                              RESTORED);
 
       /* do not reset the hibernating flag yet -- we will do that when the app
        * creates its first window
