@@ -661,9 +661,15 @@ hd_home_background_apply_async_dbus_callback (DBusGProxy       *proxy,
 
   if (pixmap)
     {
+      GdkColormap *colormap;
+
       g_object_weak_ref (G_OBJECT (pixmap),
                          (GWeakNotify)free_pixmap,
                          GINT_TO_POINTER((GDK_PIXMAP_XID (pixmap))));
+
+      colormap = gdk_drawable_get_colormap (GDK_DRAWABLE (data->window));
+      gdk_drawable_set_colormap (GDK_DRAWABLE (pixmap), colormap);
+
       gdk_window_set_back_pixmap (data->window, pixmap, FALSE);
       g_object_unref (pixmap);
     }
