@@ -41,6 +41,7 @@
 #include <hildon/hildon-banner.h>
 #include <hildon/hildon-note.h>
 #include <hildon/hildon-defines.h>
+#include <hildon/hildon-helper.h>
 #else
 #include <hildon-widgets/hildon-banner.h>
 #include <hildon-widgets/hildon-note.h>
@@ -141,11 +142,13 @@ hd_home_window_help_activate (HDHomeWindow *window);
 static void
 hd_home_window_set_background_activate (HDHomeWindow *window);
 
+#ifndef HAVE_LIBHILDON
 static void
 hd_home_window_settings_insensitive_press_cb (HDHomeWindow *window);
 
 static void
 hd_home_window_layout_insensitive_press_cb (HDHomeWindow *window);
+#endif
 
 static GtkWidget *
 hd_home_window_build_main_menu (HDHomeWindow *window);
@@ -188,9 +191,11 @@ static void
 hd_home_window_show_information_note (HDHomeWindow *window,
                                       const gchar *text);
 
+#ifndef HAVE_LIBHILDON
 static void
 hd_home_window_show_information_banner (HDHomeWindow *window,
                                         const gchar *text);
+#endif
 
 static void
 hd_home_window_class_init (HDHomeWindowClass *window_class)
@@ -651,9 +656,13 @@ hd_home_window_build_main_menu (HDHomeWindow *window)
   /* Applet settings menu item */
   settings_menu = gtk_menu_new ();
   menu_item = gtk_menu_item_new_with_label (HH_MENU_APPLET_SETTINGS);
+#ifdef HAVE_LIBHILDON
+  hildon_helper_set_insensitive_message (menu_item, HH_APPLET_SETTINGS_BANNER);
+#else
   g_signal_connect_swapped (menu_item, "insensitive-press",
                             G_CALLBACK (hd_home_window_settings_insensitive_press_cb),
                             window);
+#endif
   gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_item), settings_menu);
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
   gtk_widget_set_sensitive (menu_item, FALSE);
@@ -666,9 +675,13 @@ hd_home_window_build_main_menu (HDHomeWindow *window)
   g_signal_connect_swapped (menu_item, "activate",
                             G_CALLBACK (hildon_home_window_layout_mode_activate),
                             window);
+#ifdef HAVE_LIBHILDON
+  hildon_helper_set_insensitive_message (menu_item, HH_LAYOUT_UNAVAIL_BANNER);
+#else
   g_signal_connect_swapped (menu_item, "insensitive-press",
                             G_CALLBACK (hd_home_window_layout_insensitive_press_cb),
                             window);
+#endif
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
   gtk_widget_set_sensitive (menu_item, FALSE);
   gtk_widget_show (menu_item);
@@ -872,6 +885,7 @@ hd_home_window_personalisation_activate (HDHomeWindow *window)
 }
 #endif
 
+#ifndef HAVE_LIBHILDON
 static void
 hd_home_window_settings_insensitive_press_cb (HDHomeWindow *window)
 {
@@ -887,6 +901,7 @@ hd_home_window_layout_insensitive_press_cb (HDHomeWindow *window)
                                           HH_LAYOUT_UNAVAIL_BANNER);
 
 }
+#endif
 
 static void
 hd_home_window_ensure_menu_status (HDHomeWindow *window)
@@ -1160,7 +1175,9 @@ hd_home_window_set_background_activate (HDHomeWindow *window)
   GtkWidget                *dialog;
 
   dialog = g_object_new (HD_TYPE_HOME_BACKGROUND_DIALOG,
+#ifdef HAVE_LIBOSSO
                          "osso-context", priv->osso_context,
+#endif
                          "background-dir", HD_DESKTOP_BACKGROUNDS_PATH,
                          "background", priv->background,
                          NULL);
@@ -1186,6 +1203,7 @@ hd_home_window_show_information_note (HDHomeWindow *window,
     gtk_widget_destroy (GTK_WIDGET (note));
 }
 
+#ifndef HAVE_LIBHILDON
 static void
 hd_home_window_show_information_banner (HDHomeWindow *window,
                                         const gchar *text)
@@ -1196,3 +1214,4 @@ hd_home_window_show_information_banner (HDHomeWindow *window,
                                   NULL,
                                   text);
 }
+#endif
